@@ -36,7 +36,7 @@ set -o errexit
 # send your bug reports to contact@dotslashplay.it
 ###
 
-script_version=20210513.10
+script_version=20210725.1
 
 # Set game-specific variables
 
@@ -101,19 +101,19 @@ ARCHIVE_DOC0_FILES='*.txt'
 ARCHIVE_DOC1_PATH='data/noarch/doc'
 ARCHIVE_DOC1_FILES='*'
 
-ARCHIVE_GAME_BIN32_PATH_BASE_GOG='data/noarch/game'
-ARCHIVE_GAME_BIN32_PATH_BASE_HUMBLE='linux'
-ARCHIVE_GAME_BIN32_PATH_BASE_HUMBLE_ALTPATH='.'
+ARCHIVE_GAME_BIN32_PATH_GOG='data/noarch/game'
+ARCHIVE_GAME_BIN32_PATH_HUMBLE='linux'
+ARCHIVE_GAME_BIN32_PATH_HUMBLE_ALTPATH='.'
 ARCHIVE_GAME_BIN32_FILES='*.x86 *_Data/*/x86'
 
-ARCHIVE_GAME_BIN64_PATH_BASE_GOG='data/noarch/game'
-ARCHIVE_GAME_BIN64_PATH_BASE_HUMBLE='linux'
-ARCHIVE_GAME_BIN64_PATH_BASE_HUMBLE_ALTPATH='.'
+ARCHIVE_GAME_BIN64_PATH_GOG='data/noarch/game'
+ARCHIVE_GAME_BIN64_PATH_HUMBLE='linux'
+ARCHIVE_GAME_BIN64_PATH_HUMBLE_ALTPATH='.'
 ARCHIVE_GAME_BIN64_FILES='*.x86_64 *_Data/*/x86_64'
 
-ARCHIVE_GAME_DATA_PATH_BASE_GOG='data/noarch/game'
-ARCHIVE_GAME_DATA_PATH_BASE_HUMBLE='linux'
-ARCHIVE_GAME_DATA_PATH_BASE_HUMBLE_ALTPATH='.'
+ARCHIVE_GAME_DATA_PATH_GOG='data/noarch/game'
+ARCHIVE_GAME_DATA_PATH_HUMBLE='linux'
+ARCHIVE_GAME_DATA_PATH_HUMBLE_ALTPATH='.'
 ARCHIVE_GAME_DATA_FILES='*_Data'
 
 APP_MAIN_TYPE='native'
@@ -152,16 +152,16 @@ APP_OPTIONS="${APP_OPTIONS} -logFile ./logs/$(date +%F-%R).log"'
 
 # Keep compatibility with old versions
 
-APP_MAIN_EXE_BIN32_BASE_GOG_OLDNAME='140.x86'
-APP_MAIN_EXE_BIN64_BASE_GOG_OLDNAME='140.x86_64'
-APP_MAIN_ICON_BASE_GOG_OLDNAME='140_Data/Resources/UnityPlayer.png'
+APP_MAIN_EXE_BIN32_GOG_OLDNAME='140.x86'
+APP_MAIN_EXE_BIN64_GOG_OLDNAME='140.x86_64'
+APP_MAIN_ICON_GOG_OLDNAME='140_Data/Resources/UnityPlayer.png'
 
-APP_MAIN_EXE_BIN32_BASE_HUMBLE_OLDNAME='140.x86'
-APP_MAIN_EXE_BIN64_BASE_HUMBLE_OLDNAME='140.x86_64'
-APP_MAIN_ICON_BASE_HUMBLE_OLDNAME='140_Data/Resources/UnityPlayer.png'
-ARCHIVE_GAME_BIN32_PATH_BASE_HUMBLE_OLDNAME="$ARCHIVE_GAME_BIN32_PATH_BASE_HUMBLE_ALTPATH"
-ARCHIVE_GAME_BIN64_PATH_BASE_HUMBLE_OLDNAME="$ARCHIVE_GAME_BIN64_PATH_BASE_HUMBLE_ALTPATH"
-ARCHIVE_GAME_DATA_PATH_BASE_HUMBLE_OLDNAME="$ARCHIVE_GAME_DATA_PATH_BASE_HUMBLE_ALTPATH"
+APP_MAIN_EXE_BIN32_HUMBLE_OLDNAME='140.x86'
+APP_MAIN_EXE_BIN64_HUMBLE_OLDNAME='140.x86_64'
+APP_MAIN_ICON_HUMBLE_OLDNAME='140_Data/Resources/UnityPlayer.png'
+ARCHIVE_GAME_BIN32_PATH_HUMBLE_OLDNAME="$ARCHIVE_GAME_BIN32_PATH_HUMBLE_ALTPATH"
+ARCHIVE_GAME_BIN64_PATH_HUMBLE_OLDNAME="$ARCHIVE_GAME_BIN64_PATH_HUMBLE_ALTPATH"
+ARCHIVE_GAME_DATA_PATH_HUMBLE_OLDNAME="$ARCHIVE_GAME_DATA_PATH_HUMBLE_ALTPATH"
 
 # Load common functions
 
