@@ -2,7 +2,8 @@
 set -o errexit
 
 ###
-# Copyright (c) 2015-2020, Antoine "vv221/vv222" Le Gonidec
+# Copyright (c) 2015-2021, Antoine Le Gonidec <vv221@dotslashplay.it>
+# Copyright (c) 2020-2021, Hoël Bézier
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -34,19 +35,22 @@ set -o errexit
 # send your bug reports to contact@dotslashplay.it
 ###
 
-script_version=20200709.2
+script_version=20210423.1
 
 # Set game-specific variables
 
 GAME_ID='age-of-mythology-demo'
 GAME_NAME='Age of Mythology Demo'
 
-ARCHIVE_MAIN='mtrial.exe'
-ARCHIVE_MAIN_URL='https://archive.org/details/AgeOfMythologyDemo'
-ARCHIVE_MAIN_MD5='c475268b774c0fd469802e915b3c3803'
-ARCHIVE_MAIN_TYPE='cabinet'
-ARCHIVE_MAIN_VERSION='1.0-archiveorg1'
-ARCHIVE_MAIN_SIZE='550000'
+ARCHIVES_LIST='
+ARCHIVE_BASE_0'
+
+ARCHIVE_BASE_0='mtrial.exe'
+ARCHIVE_BASE_0_MD5='c475268b774c0fd469802e915b3c3803'
+ARCHIVE_BASE_0_TYPE='cabinet'
+ARCHIVE_BASE_0_VERSION='1.0-archiveorg1'
+ARCHIVE_BASE_0_SIZE='550000'
+ARCHIVE_BASE_0_URL='https://archive.org/details/AgeOfMythologyDemo'
 
 ARCHIVE_DOC_DATA_PATH='.'
 ARCHIVE_DOC_DATA_FILES='*.rtf'
@@ -84,16 +88,15 @@ PKG_BIN_DEPS="$PKG_DATA_ID wine glx"
 
 # Load common functions
 
-target_version='2.11'
+target_version='2.12'
 
 if [ -z "$PLAYIT_LIB2" ]; then
-	: "${XDG_DATA_HOME:="$HOME/.local/share"}"
-	for path in\
-		"$PWD"\
-		"$XDG_DATA_HOME/play.it"\
-		'/usr/local/share/games/play.it'\
-		'/usr/local/share/play.it'\
-		'/usr/share/games/play.it'\
+	for path in \
+		"$PWD" \
+		"${XDG_DATA_HOME:="$HOME/.local/share"}/play.it" \
+		'/usr/local/share/games/play.it' \
+		'/usr/local/share/play.it' \
+		'/usr/share/games/play.it' \
 		'/usr/share/play.it'
 	do
 		if [ -e "$path/libplayit2.sh" ]; then
