@@ -1,8 +1,9 @@
-#!/bin/sh -e
+#!/bin/sh
 set -o errexit
 
 ###
-# Copyright (c) 2015-2020, Antoine "vv221/vv222" Le Gonidec
+# Copyright (c) 2015-2021, Antoine Le Gonidec <vv221@dotslashplay.it>
+# Copyright (c)      2021, Anna Lea
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -30,35 +31,39 @@ set -o errexit
 
 ###
 # Gomo
-# build native Linux packages from the original installers
-# send your bug reports to vv221@dotslashplay.it
+# build native packages from the original installers
+# send your bug reports to contact@dotslashplay.it
 ###
 
-script_version=20200918.1
+script_version=20210725.2
 
 # Set game-specific variables
 
 GAME_ID='gomo'
 GAME_NAME='Gomo'
 
-ARCHIVES_LIST='ARCHIVE_GOG'
+ARCHIVE_BASE_1='setup_gomo_1.0_(20774).exe'
+ARCHIVE_BASE_1_MD5='7679c55aaafe8308518aa4940929fbb0'
+ARCHIVE_BASE_1_TYPE='innosetup'
+ARCHIVE_BASE_1_SIZE='290000'
+ARCHIVE_BASE_1_VERSION='1.0-gog20774'
+ARCHIVE_BASE_1_URL='https://www.gog.com/game/gomo'
 
-ARCHIVE_GOG='setup_gomo_2.1.0.4.exe'
-ARCHIVE_GOG_URL='https://www.gog.com/game/gomo'
-ARCHIVE_GOG_MD5='5ee422dff6f00976e170296103dd29e6'
-ARCHIVE_GOG_VERSION='1.0-gog2.1.0.4'
-ARCHIVE_GOG_SIZE='560000'
+ARCHIVE_BASE_0='setup_gomo_2.1.0.4.exe'
+ARCHIVE_BASE_0_MD5='5ee422dff6f00976e170296103dd29e6'
+ARCHIVE_BASE_0_TYPE='innosetup'
+ARCHIVE_BASE_0_SIZE='560000'
+ARCHIVE_BASE_0_VERSION='1.0-gog2.1.0.4'
 
-ARCHIVE_GAME_BIN_PATH='app'
-ARCHIVE_GAME_BIN_FILES='./gomo.exe ./adobe?air ./gomo.swf'
+ARCHIVE_GAME_BIN_PATH='.'
+ARCHIVE_GAME_BIN_FILES='gomo.exe adobe?air gomo.swf'
 
-ARCHIVE_GAME_DATA_PATH='app'
-ARCHIVE_GAME_DATA_FILES='./meta-inf ./movies ./music ./world'
+ARCHIVE_GAME_DATA_PATH='.'
+ARCHIVE_GAME_DATA_FILES='meta-inf movies music world'
 
 APP_MAIN_TYPE='wine'
 APP_MAIN_EXE='gomo.exe'
 APP_MAIN_ICON='gomo.exe'
-APP_MAIN_ICON_RES='16 32 48 128'
 
 PACKAGES_LIST='PKG_BIN PKG_DATA'
 
@@ -66,24 +71,34 @@ PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
 PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID wine"
+PKG_BIN_DEPS="${PKG_DATA_ID} wine"
+
+# Use persistent storage for saved progression
+
+APP_WINE_LINK_DIRS="$APP_WINE_LINK_DIRS"'
+userdata:users/${USER}/Application Data/Gomo'
+DATA_FILES="$DATA_FILES userdata/Local?Store/saves.dat"
+
+# Keep compatibility with old archives
+
+ARCHIVE_GAME_BIN_PATH_0='app'
+ARCHIVE_GAME_DATA_PATH_0='app'
 
 # Load common functions
 
-target_version='2.3'
+target_version='2.13'
 
 if [ -z "$PLAYIT_LIB2" ]; then
-	: "${XDG_DATA_HOME:="$HOME/.local/share"}"
-	for path in\
-		"$PWD"\
-		"$XDG_DATA_HOME/play.it"\
-		'/usr/local/share/games/play.it'\
-		'/usr/local/share/play.it'\
-		'/usr/share/games/play.it'\
+	for path in \
+		"$PWD" \
+		"${XDG_DATA_HOME:="$HOME/.local/share"}/play.it" \
+		'/usr/local/share/games/play.it' \
+		'/usr/local/share/play.it' \
+		'/usr/share/games/play.it' \
 		'/usr/share/play.it'
 	do
-		if [ -e "$path/libplayit2.sh" ]; then
-			PLAYIT_LIB2="$path/libplayit2.sh"
+		if [ -e "${path}/libplayit2.sh" ]; then
+			PLAYIT_LIB2="${path}/libplayit2.sh"
 			break
 		fi
 	done
@@ -93,27 +108,28 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
-#shellcheck source=play.it-2/lib/libplayit2.sh
+# shellcheck source=play.it-2/lib/libplayit2.sh
 . "$PLAYIT_LIB2"
 
 # Extract game data
 
 extract_data_from "$SOURCE_ARCHIVE"
-set_standard_permissions "$PLAYIT_WORKDIR/gamedata"
+prepare_package_layout
 
-for PKG in $PACKAGES_LIST; do
-	organize_data "GAME_${PKG#PKG_}" "$PATH_GAME"
-done
+# Extract icons
 
 PKG='PKG_BIN'
-extract_and_sort_icons_from 'APP_MAIN'
+icons_get_from_package 'APP_MAIN'
+icons_move_to 'PKG_DATA'
 
-rm --recursive "$PLAYIT_WORKDIR/gamedata"
+# Clean up temporary files
+
+rm --recursive "${PLAYIT_WORKDIR}/gamedata"
 
 # Write launchers
 
 PKG='PKG_BIN'
-write_launcher 'APP_MAIN'
+launchers_write 'APP_MAIN'
 
 # Build package
 
@@ -122,7 +138,7 @@ build_pkg
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+rm --recursive "${PLAYIT_WORKDIR}"
 
 # Print instructions
 
