@@ -2,7 +2,7 @@
 set -o errexit
 
 ###
-# Copyright (c) 2015-2020, Antoine "vv221/vv222" Le Gonidec
+# Copyright (c) 2015-2021, Antoine Le Gonidec <vv221@dotslashplay.it>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -34,67 +34,60 @@ set -o errexit
 # send your bug reports to contact@dotslashplay.it
 ###
 
-script_version=20200924.2
+script_version=20210520.1
 
 # Set game-specific variables
 
 GAME_ID='opus-magnum'
 GAME_NAME='Opus Magnum'
 
-ARCHIVES_LIST='
-ARCHIVE_GOG_0'
+ARCHIVE_BASE_1='opus_magnum_11_14_2020_43144.sh'
+ARCHIVE_BASE_1_MD5='2defb1198c5a5778eb9ac20ff201f086'
+ARCHIVE_BASE_1_TYPE='mojosetup'
+ARCHIVE_BASE_1_SIZE='520000'
+ARCHIVE_BASE_1_VERSION='2020.11.14-gog43144'
+ARCHIVE_BASE_1_URL='https://www.gog.com/game/opus_magnum'
 
-ARCHIVE_GOG_0='opus_magnum_en_17_08_2018_update_23270.sh'
-ARCHIVE_GOG_0_URL='https://www.gog.com/game/opus_magnum'
-ARCHIVE_GOG_0_TYPE='mojosetup'
-ARCHIVE_GOG_0_MD5='dbe5137d4b7e2edd21f4117a80756872'
-ARCHIVE_GOG_0_SIZE='460000'
-ARCHIVE_GOG_0_VERSION='2018.08.17-gog23270'
+ARCHIVE_BASE_0='opus_magnum_en_17_08_2018_update_23270.sh'
+ARCHIVE_BASE_0_MD5='dbe5137d4b7e2edd21f4117a80756872'
+ARCHIVE_BASE_0_TYPE='mojosetup'
+ARCHIVE_BASE_0_SIZE='460000'
+ARCHIVE_BASE_0_VERSION='2018.08.17-gog23270'
 
-ARCHIVE_DOC_DATA_PATH='data/noarch/game'
-ARCHIVE_DOC_DATA_FILES='*.txt'
+ARCHIVE_DOC_MAIN_PATH='data/noarch/game'
+ARCHIVE_DOC_MAIN_FILES='*.txt'
 
-ARCHIVE_GAME_BIN32_PATH='data/noarch/game'
-ARCHIVE_GAME_BIN32_FILES='Lightning.bin.x86 lib/libCSteamworks.so lib/libsteam_api.so'
+ARCHIVE_GAME_MAIN_PATH='data/noarch/game'
+ARCHIVE_GAME_MAIN_FILES='Content PackedContent monoconfig monomachineconfig Lightning.exe Lightning.exe.config Ionic.Zip.Reduced.dll Steamworks.NET.dll'
 
-ARCHIVE_GAME_BIN64_PATH='data/noarch/game'
-ARCHIVE_GAME_BIN64_FILES='Lightning.bin.x86_64 lib64/libCSteamworks.so lib64/libsteam_api.so'
-
-ARCHIVE_GAME_DATA_PATH='data/noarch/game'
-ARCHIVE_GAME_DATA_FILES='*.dll *.exe *.exe.config mono* Content PackedContent'
-
-APP_MAIN_TYPE='native'
-APP_MAIN_EXE_BIN32='Lightning.bin.x86'
-APP_MAIN_EXE_BIN64='Lightning.bin.x86_64'
+APP_MAIN_TYPE='mono'
+APP_MAIN_EXE='Lightning.exe'
 APP_MAIN_ICON='Lightning.exe'
 
-PACKAGES_LIST='PKG_BIN32 PKG_BIN64 PKG_DATA'
+PACKAGES_LIST='PKG_MAIN'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
+PKG_MAIN_DEPS='mono sdl2 sdl2_image sdl2_mixer vorbis glx'
+PKG_MAIN_DEPS_DEB='libmono-posix4.0-cil, libmono-security4.0-cil, libmono-system4.0-cil, libmono-system-configuration4.0-cil, libmono-system-core4.0-cil, libmono-system-data4.0-cil, libmono-system-drawing4.0-cil, libmono-system-security4.0-cil, libmono-system-web4.0-cil, libmono-system-web-extensions4.0-cil, libmono-system-web-http4.0-cil, libmono-system-web-services4.0-cil, libmono-system-xml4.0-cil'
 
-PKG_BIN32_ARCH='32'
-PKG_BIN32_DEPS="$PKG_DATA_ID glibc libstdc++ sdl2 sdl2_image sdl2_mixer vorbis"
+# Ensure easy upgrade from packages generated with pre-20210506.1 script
 
-PKG_BIN64_ARCH='64'
-PKG_BIN64_DEPS="$PKG_BIN32_DEPS"
+PKG_MAIN_PROVIDE='opus-magnum-data'
 
 # Load common functions
 
-target_version='2.11'
+target_version='2.13'
 
 if [ -z "$PLAYIT_LIB2" ]; then
-	: "${XDG_DATA_HOME:="$HOME/.local/share"}"
-	for path in\
-		"$PWD"\
-		"$XDG_DATA_HOME/play.it"\
-		'/usr/local/share/games/play.it'\
-		'/usr/local/share/play.it'\
-		'/usr/share/games/play.it'\
+	for path in \
+		"$PWD" \
+		"${XDG_DATA_HOME:="$HOME/.local/share"}/play.it" \
+		'/usr/local/share/games/play.it' \
+		'/usr/local/share/play.it' \
+		'/usr/share/games/play.it' \
 		'/usr/share/play.it'
 	do
-		if [ -e "$path/libplayit2.sh" ]; then
-			PLAYIT_LIB2="$path/libplayit2.sh"
+		if [ -e "${path}/libplayit2.sh" ]; then
+			PLAYIT_LIB2="${path}/libplayit2.sh"
 			break
 		fi
 	done
@@ -114,18 +107,15 @@ prepare_package_layout
 
 # Extract icon
 
-PKG='PKG_DATA'
 icons_get_from_package 'APP_MAIN'
 
 # Clean up temporary files
 
-rm --recursive "$PLAYIT_WORKDIR/gamedata"
+rm --recursive "${PLAYIT_WORKDIR}/gamedata"
 
 # Write launchers
 
-for PKG in 'PKG_BIN32' 'PKG_BIN64'; do
-	launchers_write 'APP_MAIN'
-done
+launchers_write 'APP_MAIN'
 
 # Build package
 
