@@ -35,7 +35,7 @@ set -o errexit
 # send your bug reports to contact@dotslashplay.it
 ###
 
-script_version=20201017.1
+script_version=20201026.2
 
 # Set game-specific variables
 
@@ -44,30 +44,43 @@ SCRIPT_DEPS='find dos2unix'
 GAME_ID='owlboy'
 GAME_NAME='Owlboy'
 
-ARCHIVE_HUMBLE='owlboy-03152019-bin'
-ARCHIVE_HUMBLE_URL='https://www.humblebundle.com/store/owlboy'
-ARCHIVE_HUMBLE_MD5='2966b183f43f220ade646cb3f7872c49'
-ARCHIVE_HUMBLE_SIZE='550000'
-ARCHIVE_HUMBLE_VERSION='1.3.7013.40178-humble190325'
-ARCHIVE_HUMBLE_TYPE='mojosetup'
+ARCHIVES_LIST='
+ARCHIVE_HUMBLE_0
+ARCHIVE_MULTIARCH_HUMBLE_3
+ARCHIVE_MULTIARCH_HUMBLE_2
+ARCHIVE_MULTIARCH_HUMBLE_1
+ARCHIVE_MULTIARCH_HUMBLE_0'
 
-ARCHIVE_HUMBLE_OLD2='owlboy-12292017.bin'
-ARCHIVE_HUMBLE_OLD2_MD5='c2e99502013c7d2529bc2aefb6416dcf'
-ARCHIVE_HUMBLE_OLD2_SIZE='570000'
-ARCHIVE_HUMBLE_OLD2_VERSION='1.3.6564.30139-humble1'
-ARCHIVE_HUMBLE_OLD2_TYPE='mojosetup'
+ARCHIVE_HUMBLE_0='owlboy-01302020-bin'
+ARCHIVE_HUMBLE_0_MD5='0d8d67c79b9359ee4b79913b6b640465'
+ARCHIVE_HUMBLE_0_TYPE='mojosetup'
+ARCHIVE_HUMBLE_0_URL='https://www.humblebundle.com/store/owlboy'
+ARCHIVE_HUMBLE_0_SIZE='550000'
+ARCHIVE_HUMBLE_0_VERSION='1.3.7013.40718-humble200130'
 
-ARCHIVE_HUMBLE_OLD1='owlboy-11022017-bin'
-ARCHIVE_HUMBLE_OLD1_MD5='d3a1e4753a604431c58eb1ea26c35543'
-ARCHIVE_HUMBLE_OLD1_SIZE='570000'
-ARCHIVE_HUMBLE_OLD1_VERSION='1.3.6515.19883-humble171102'
-ARCHIVE_HUMBLE_OLD1_TYPE='mojosetup'
+ARCHIVE_MULTIARCH_HUMBLE_3='owlboy-03152019-bin'
+ARCHIVE_MULTIARCH_HUMBLE_3_MD5='2966b183f43f220ade646cb3f7872c49'
+ARCHIVE_MULTIARCH_HUMBLE_3_TYPE='mojosetup'
+ARCHIVE_MULTIARCH_HUMBLE_3_SIZE='550000'
+ARCHIVE_MULTIARCH_HUMBLE_3_VERSION='1.3.7013.40178-humble190325'
 
-ARCHIVE_HUMBLE_OLD0='owlboy-05232017-bin'
-ARCHIVE_HUMBLE_OLD0_MD5='f35fba69fadffbf498ca8a38dbceeac1'
-ARCHIVE_HUMBLE_OLD0_SIZE='570000'
-ARCHIVE_HUMBLE_OLD0_VERSION='1.2.6382.15868-humble1'
-ARCHIVE_HUMBLE_OLD0_TYPE='mojosetup'
+ARCHIVE_MULTIARCH_HUMBLE_2='owlboy-12292017.bin'
+ARCHIVE_MULTIARCH_HUMBLE_2_MD5='c2e99502013c7d2529bc2aefb6416dcf'
+ARCHIVE_MULTIARCH_HUMBLE_2_TYPE='mojosetup'
+ARCHIVE_MULTIARCH_HUMBLE_2_SIZE='570000'
+ARCHIVE_MULTIARCH_HUMBLE_2_VERSION='1.3.6564.30139-humble1'
+
+ARCHIVE_MULTIARCH_HUMBLE_1='owlboy-11022017-bin'
+ARCHIVE_MULTIARCH_HUMBLE_1_MD5='d3a1e4753a604431c58eb1ea26c35543'
+ARCHIVE_MULTIARCH_HUMBLE_1_TYPE='mojosetup'
+ARCHIVE_MULTIARCH_HUMBLE_1_SIZE='570000'
+ARCHIVE_MULTIARCH_HUMBLE_1_VERSION='1.3.6515.19883-humble171102'
+
+ARCHIVE_MULTIARCH_HUMBLE_0='owlboy-05232017-bin'
+ARCHIVE_MULTIARCH_HUMBLE_0_MD5='f35fba69fadffbf498ca8a38dbceeac1'
+ARCHIVE_MULTIARCH_HUMBLE_0_TYPE='mojosetup'
+ARCHIVE_MULTIARCH_HUMBLE_0_SIZE='570000'
+ARCHIVE_MULTIARCH_HUMBLE_0_VERSION='1.2.6382.15868-humble1'
 
 ARCHIVE_DOC_DATA_PATH='data'
 ARCHIVE_DOC_DATA_FILES='Linux.README'
@@ -89,7 +102,8 @@ APP_MAIN_LIBS_BIN64='lib64'
 APP_MAIN_EXE='Owlboy.exe'
 APP_MAIN_ICON='Owlboy.bmp'
 
-PACKAGES_LIST='PKG_DATA PKG_BIN32 PKG_BIN64'
+PACKAGES_LIST='PKG_DATA PKG_BIN64'
+PACKAGES_LIST_MULTIARCH='PKG_DATA PKG_BIN32 PKG_BIN64'
 
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
@@ -133,6 +147,16 @@ fi
 # shellcheck source=play.it-2/lib/libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Update list of packages to build, based on source archive
+
+###
+# TODO
+# This should always be done by the library
+###
+use_archive_specific_value 'PACKAGES_LIST'
+# shellcheck disable=SC2086
+set_temp_directories $PACKAGES_LIST
+
 # Extract game data
 
 extract_data_from "$SOURCE_ARCHIVE"
@@ -152,9 +176,14 @@ fi
 
 # Write launchers
 
-for PKG in 'PKG_BIN32' 'PKG_BIN64'; do
-	launchers_write 'APP_MAIN'
-done
+PKG='PKG_BIN64'
+launchers_write 'APP_MAIN'
+case "$ARCHIVE" in
+	('ARCHIVE_MULTIARCH'*)
+		PKG='PKG_BIN32'
+		launchers_write 'APP_MAIN'
+	;;
+esac
 
 # Build package
 
