@@ -14,6 +14,7 @@ archive_initialize_required() {
 	# Throw an error if no archive candidate has been found
 	if [ -z "$archive_candidate" ]; then
 		error_archive_not_found "$@"
+		return 1
 	fi
 
 	# Call common part of archive initialization
@@ -128,47 +129,53 @@ archive_find_from_candidates() {
 }
 
 # return the absolute path to a given archive
-# USAGE: archive_find_path $archive_name
+# USAGE: archive_find_path $archive
 # RETURNS: an absolute file path, or nothing
 archive_find_path() {
-	local archive_name archive_filename archive_path
-	archive_name="$1"
+	local archive
+	archive="$1"
 
-	# Right now, an archive can only be found using its file name
-	archive_filename=$(get_value "$archive_name")
-	archive_path=$(archive_find_path_from_name "$archive_filename")
+	local archive_name
+	archive_name=$(get_value "$archive")
 
-	printf '%s' "$archive_path"
-	return 0
+	archive_find_path_from_name "$archive_name"
 }
 
 # find an archive from its file name
-# USAGE: archive_find_path_from_name $file_name
+# USAGE: archive_find_path_from_name $archive_name
 # RETURNS: an absolute file path, or nothing
 archive_find_path_from_name() {
-	local file_name
-	file_name="$1"
+	local archive_name
+	archive_name="$1"
 
-	###
-	# TODO
-	# Check that the provided file name is not empty
-	###
+	# If the passed name starts with "/",
+	# assume it is an absolute path to the archive file.
+	if printf '%s' "$archive_name" | grep --quiet '^/'; then
+		if [ -f "$archive_name" ]; then
+			printf '%s' "$archive_name"
+		fi
+		# No archive found at the given absolute path,
+		# return nothing.
+		return 0
+	fi
 
 	# Look for the archive in current directory
-	if [ -f "$PWD/$file_name" ]; then
-		file_path=$(realpath "$PWD/$file_name")
-		printf '%s' "$file_name"
+	local archive_path
+	archive_path="${PWD}/${archive_name}"
+	if [ -f "$archive_path" ]; then
+		realpath "$archive_path"
 		return 0
 	fi
 
 	# Look for the archive in the same directory than the main archive
-	if \
-		[ -n "$SOURCE_ARCHIVE" ] && \
-		[ -f "$(dirname "$SOURCE_ARCHIVE")/$file_name" ]
-	then
-		file_path=$(realpath "$(dirname "$SOURCE_ARCHIVE")/$file_name")
-		printf '%s' "$file_path"
-		return 0
+	if [ -n "$SOURCE_ARCHIVE" ]; then
+		local source_directory
+		source_directory=$(dirname "$SOURCE_ARCHIVE")
+		archive_path="${source_directory}/${archive_name}"
+		if [ -f "$archive_path" ]; then
+			realpath "$archive_path"
+			return 0
+		fi
 	fi
 
 	# No archive found, return nothing
@@ -253,7 +260,6 @@ archive_add_size_to_total() {
 # RETURNS: an archive type
 archive_get_type() {
 	# Get the archive identifier, check that it is not empty
-	# shellcheck disable=SC2039
 	local archive_identifier
 	archive_identifier="$1"
 	if [ -z "$archive_identifier" ]; then
@@ -262,7 +268,6 @@ archive_get_type() {
 	fi
 
 	# Return archive type early if it is already set
-	# shellcheck disable=SC2039
 	local archive_type
 	archive_type=$(get_value "${archive_identifier}_TYPE")
 	if [ -n "$archive_type" ]; then
@@ -271,7 +276,6 @@ archive_get_type() {
 	fi
 
 	# Guess archive type from its file name
-	# shellcheck disable=SC2039
 	local archive_file
 	archive_file=$(get_value "$archive_identifier")
 	case "$archive_file" in
@@ -308,8 +312,12 @@ archive_get_type() {
 		(*'.7z')
 			archive_type='7z'
 		;;
+		(*'.tar.xz'|*'.txz')
+			archive_type='tar.xz'
+		;;
 		(*)
 			error_archive_type_not_set "$archive_identifier"
+			return 1
 		;;
 	esac
 
@@ -337,6 +345,7 @@ archive_integrity_check() {
 		;;
 		(*)
 			error_invalid_argument 'OPTION_CHECKSUM' 'archive_integrity_check'
+			return 1
 		;;
 	esac
 }
@@ -354,13 +363,11 @@ archives_return_list() {
 	fi
 
 	# Parse the calling script to guess the identifiers of the archives it supports
-	# shellcheck disable=SC2039
 	local script pattern
 	script="$0"
 
 	# Try to find archives using the ARCHIVE_BASE_xxx_[0-9]+ naming scheme
 	# Fall back to the older naming scheme for scripts targeting a library older than 2.13
-	# shellcheck disable=SC2039
 	local archives_list pattern
 	# shellcheck disable=SC2154
 	if version_is_at_least '2.13' "$target_version"; then
