@@ -1,9 +1,5 @@
 # set temporary directories
 # USAGE: set_temp_directories $pkg[…]
-# NEEDED VARS: (ARCHIVE_SIZE) GAME_ID (LANG) (PWD) (XDG_CACHE_HOME) (XDG_RUNTIME_DIR)
-# CALLS: testvar temporary_directories_find_base check_directory_is_case_sensitive
-#	check_directory_supports_unix_permissions
-# SETS: PLAYIT_WORKDIR postinst prerm
 set_temp_directories() {
 	local base_directory
 
@@ -13,23 +9,10 @@ set_temp_directories() {
 	[ "$PLAYIT_WORKDIR" ] && rm --force --recursive "$PLAYIT_WORKDIR"
 
 	# Look for a directory with enough free space to work in
-	# shellcheck disable=SC2039
 	base_directory=$(temporary_directories_find_base)
 
-	# Check that the candidate temporary directory is on a case-sensitive filesystem
-	if ! check_directory_is_case_sensitive "$base_directory"; then
-		error_case_insensitive_filesystem_is_not_supported "$base_directory"
-		return 1
-	fi
-
-	# Check that the candidate temporary directory is on a filesystem with support for UNIX permissions
-	if ! check_directory_supports_unix_permissions "$base_directory"; then
-		error_unix_permissions_support_is_required "$base_directory"
-		return 1
-	fi
-
 	# Generate a directory with a unique name for the current instance
-	PLAYIT_WORKDIR="$(mktemp --directory --tmpdir="$base_directory" "${GAME_ID}.XXXXX")"
+	PLAYIT_WORKDIR="$(mktemp --directory --tmpdir="$base_directory" "$(game_id).XXXXX")"
 	debug_option_value 'PLAYIT_WORKDIR'
 	debug_creating_directory "$PLAYIT_WORKDIR"
 	export PLAYIT_WORKDIR
@@ -44,11 +27,11 @@ set_temp_directories() {
 	# Export the path to the packages to build as PKG_xxx_PATH
 	# Some game scripts are expecting this variable to be set
 	# These should be updated to call `package_get_path` instead
-	# shellcheck disable=SC2039
-	local package
+	local package package_path
 	for package in "$@"; do
 		testvar "$package" 'PKG'
-		eval "${package}_PATH='$(package_get_path "$package")'"
+		package_path=$(package_get_path "$package")
+		eval "${package}_PATH='${package_path}'"
 		export "${package?}_PATH"
 	done
 
@@ -75,16 +58,9 @@ temporary_directories_list_candidates() {
 temporary_directories_find_base() {
 	debug_entering_function 'temporary_directories_find_base' 2
 
-	# shellcheck disable=SC2039
-	local base_directory
-	if [ $NO_FREE_SPACE_CHECK -eq 1 ]; then
-		# If free space check has been explicitely disabled,
-		# use the first directory returned by temporary_directories_list_candidates
-		# shellcheck disable=SC2039
-		local default_directory
-		default_directory="$(temporary_directories_list_candidates | head --lines=1)"
-		base_directory=$(temporary_directories_full_path "$default_directory")
-	else
+	local base_directory candidate_directory
+	if [ "$NO_FREE_SPACE_CHECK" -eq 0 ]; then
+		local free_space_required free_space_available
 		###
 		# TODO
 		# The required free space should be returned by a dedicated function,
@@ -95,41 +71,53 @@ temporary_directories_find_base() {
 			error_variable_not_set 'temporary_directories_find_base' 'ARCHIVE_SIZE'
 			return 1
 		fi
-
-		# Scan candidate directories to find one with enough free space to use for storing temporary files
-		# shellcheck disable=SC2039
-		local free_space_required free_space_available candidate_directory
 		free_space_required=$((ARCHIVE_SIZE * 2))
-		while read -r candidate_directory
-		do
-			if [ ! -d "$candidate_directory" ]; then
-				debug_temp_dir_nonexistant "$candidate_directory"
-				continue
-			fi
-			if [ ! -w "$candidate_directory" ]; then
-				debug_temp_dir_nonwritable "$candidate_directory"
-				continue
-			fi
+	fi
+
+	# Scan candidate directories to find one with enough free space to use for storing temporary files
+	while read -r candidate_directory
+	do
+		if [ ! -d "$candidate_directory" ]; then
+			debug_temp_dir_nonexistant "$candidate_directory"
+			continue
+		fi
+		if [ ! -w "$candidate_directory" ]; then
+			debug_temp_dir_nonwritable "$candidate_directory"
+			continue
+		fi
+		# Check that the candidate temporary directory is on a case-sensitive filesystem
+		if ! check_directory_is_case_sensitive "$candidate_directory"; then
+			debug_temp_dir_case_insensitive_not_supported "$candidate_directory"
+			continue
+		fi
+		# Check that the candidate temporary directory is on a filesystem with
+		# support for UNIX permissions
+		if ! check_directory_supports_unix_permissions "$candidate_directory"; then
+			debug_temp_dir_no_unix_permissions "$candidate_directory"
+			continue
+		fi
+		if [ "$NO_FREE_SPACE_CHECK" -eq 0 ]; then
 			free_space_available=$(LANG=C df \
 				--block-size=1K \
 				--output=avail \
 				"$candidate_directory" 2>/dev/null | \
 				tail --lines=1)
-			if [ $free_space_available -ge $free_space_required ]; then
-				base_directory=$(temporary_directories_full_path "$candidate_directory")
-				break;
+			if [ "$free_space_available" -lt "$free_space_required" ]; then
+				debug_temp_dir_not_enough_space "$candidate_directory"
+				continue
 			fi
-			debug_temp_dir_not_enough_space "$candidate_directory"
-		done <<- EOF
-		$(temporary_directories_list_candidates)
-		EOF
-
-		# Fail with an explicit error if no valid candidate has been found
-		if [ -z "$base_directory" ]; then
-			# shellcheck disable=SC2046
-			error_not_enough_free_space $(temporary_directories_list_candidates)
-			return 1
 		fi
+		base_directory=$(temporary_directories_full_path "$candidate_directory")
+		break;
+	done <<- EOF
+	$(temporary_directories_list_candidates)
+	EOF
+
+	# Fail with an explicit error if no valid candidate has been found
+	if [ -z "$base_directory" ]; then
+		# shellcheck disable=SC2046
+		error_no_valid_temp_dir_found $(temporary_directories_list_candidates)
+		return 1
 	fi
 
 	debug_using_directory "$base_directory"
@@ -146,11 +134,11 @@ temporary_directories_find_base() {
 #         it ends with "/play.it" if the parent directory is owned by the current user,
 #         or with "/play.it-${USER}" otherwise, where "${USER}" is the current user name
 temporary_directories_full_path() {
-	# shellcheck disable=SC2039
 	local parent_dir
 	parent_dir="$1"
 	if [ ! -d "$parent_dir" ]; then
 		error_not_a_directory "$parent_dir"
+		return 1
 	fi
 
 	if [ "$(stat -c '%u' "$parent_dir")" -eq "$(id -u)" ]; then
