@@ -28,49 +28,57 @@ prepare_package_layout() {
 }
 
 # put files from archive in the right package directories
-# USAGE: organize_data $id $path
+# USAGE: organize_data $content_id $target_path
 organize_data() {
-	local archive_path archive_files source_path destination_path source_files_pattern source_file destination_file
-
-	# get the current package
-	local package
-	package=$(package_get_current)
-
-	# Get packages list for the current game
-	local packages_list
-	packages_list=$(packages_get_list)
+	local content_id target_path
+	content_id="$1"
+	target_path="$2"
 
 	# Check that the current package is part of the target architectures
-	if [ "$OPTION_ARCHITECTURE" != 'all' ] && [ -n "${packages_list##*$package*}" ]; then
+	local package
+	package=$(package_get_current)
+	if \
+		[ "$OPTION_ARCHITECTURE" != 'all' ] \
+		&& ! packages_get_list | grep --quiet "$package"
+	then
 		warning_skip_package 'organize_data' "$package"
 		return 0
 	fi
 
-	use_archive_specific_value "ARCHIVE_${1}_PATH"
-	archive_path=$(get_value "ARCHIVE_${1}_PATH")
-	use_archive_specific_value "ARCHIVE_${1}_FILES"
-	archive_files=$(get_value "ARCHIVE_${1}_FILES")
-	destination_path="$(package_get_path "$package")${2}"
+	# Get list of files, and path to files
+	local archive_files archive_path
+	archive_files=$(get_context_specific_value 'archive'  "ARCHIVE_${content_id}_FILES")
+	if [ -z "$archive_files" ]; then
+		# No list of files for current content, skipping
+		return 0
+	fi
+	archive_path=$(get_context_specific_value 'archive' "ARCHIVE_${content_id}_PATH")
+	if [ -z "$archive_path" ]; then
+		archive_path=$(content_path_default)
+	fi
+
+	# Set path to source and destination
+	local package_path destination_path source_path
 	source_path="$PLAYIT_WORKDIR/gamedata/$archive_path"
+	package_path=$(package_get_path "$package")
+	destination_path="${package_path}${target_path}"
 
 	# When called in dry-run mode, return early
-	if [ $DRY_RUN -eq 1 ]; then
+	if [ "$DRY_RUN" -eq 1 ]; then
 		return 0
 	fi
 
-	if \
-		[ -n "$archive_path" ] && \
-		[ -n "$archive_files" ] && \
-		[ -d "$source_path" ]
-	then
+	# Proceed with the actual files inclusion
+	local source_files_pattern source_file destination_file
+	if [ -d "$source_path" ]; then
 		mkdir --parents "$destination_path"
 		set -o noglob
 		for source_files_pattern in $archive_files; do
 			set +o noglob
 			for source_file in "$source_path"/$source_files_pattern; do
 				if [ -e "$source_file" ]; then
-					debug_source_file 'Found' "$archive_path${source_file#$source_path}"
-					destination_file="${destination_path}/${source_file#$source_path}"
+					debug_source_file 'Found' "${archive_path}${source_file#"$source_path"}"
+					destination_file="${destination_path}/${source_file#"$source_path"}"
 					debug_file_to_package "$package"
 					mkdir --parents "$(dirname "$destination_file")"
 					cp \
@@ -83,7 +91,7 @@ organize_data() {
 						"$source_file" "$destination_file"
 					rm --force --recursive "$source_file"
 				else
-					debug_source_file 'Missing' "$archive_path${source_file#$source_path}"
+					debug_source_file 'Missing' "${archive_path}${source_file#"$source_path"}"
 				fi
 			done
 			set -o noglob
