@@ -4,20 +4,19 @@ launcher_write_script() {
 	# check that this has been called with exactly one argument
 	if [ "$#" -eq 0 ]; then
 		error_missing_argument 'launcher_write_script'
+		return 1
 	elif [ "$#" -gt 1 ]; then
 		error_extra_arguments 'launcher_write_script'
+		return 1
 	fi
 
-	# get the current package
+	# Check that the current package is part of the target architectures
 	local package
 	package=$(package_get_current)
-
-	# Get packages list for the current game
-	local packages_list
-	packages_list=$(packages_get_list)
-
-	# skip any action if called for a package excluded for target architectures
-	if [ "$OPTION_ARCHITECTURE" != 'all' ] && [ -n "${packages_list##*$package*}" ]; then
+	if \
+		[ "$OPTION_ARCHITECTURE" != 'all' ] \
+		&& ! packages_get_list | grep --quiet "$package"
+	then
 		warning_skip_package 'launcher_write_script' "$package"
 		return 0
 	fi
@@ -27,40 +26,27 @@ launcher_write_script() {
 	application="$1"
 	if ! testvar "$application" 'APP'; then
 		error_invalid_argument 'application' 'launcher_write_script'
+		return 1
 	fi
 
-	# get application type
-	local application_type
-	application_type="$(get_value "${application}_TYPE")"
-
-	# compute file name and path
-	local application_id
+	# compute file path
 	local target_file
-	application_id="$(get_value "${application}_ID")"
-	if [ -z "$application_id" ]; then
-		application_id="$GAME_ID"
-	fi
-	target_file="$(package_get_path "$package")${PATH_BIN}/$application_id"
+	target_file="$(package_get_path "$package")${PATH_BIN}/$(application_id "$application")"
 
 	# Check that the launcher target exists
-	local binary_file binary_path binary_found tested_package
+	local application_type binary_path binary_found tested_package
+	application_type=$(application_type "$application")
 	case "$application_type" in
 		('residualvm'|'scummvm'|'renpy')
 			# ResidualVM, ScummVM and Ren'Py games do not rely on a provided binary
 		;;
 		('mono')
 			# Game binary for Mono games may be included in another package than the binaries one
-			use_package_specific_value "${application}_EXE"
-			binary_file=$(get_value "${application}_EXE")
-
-			# Check that the name of the binary file is not empty
-			if [ -z "$binary_file" ]; then
-				error_empty_variable "${application}_EXE"
-			fi
-
+			local packages_list
+			packages_list=$(packages_get_list)
 			binary_found=0
 			for tested_package in $packages_list; do
-				binary_path="$(package_get_path "$tested_package")${PATH_GAME}/$binary_file"
+				binary_path="$(package_get_path "$tested_package")${PATH_GAME}/$(application_exe "$application")"
 				if [ -f "$binary_path" ]; then
 					binary_found=1
 					break;
@@ -70,44 +56,31 @@ launcher_write_script() {
 				[ $DRY_RUN -eq 0 ] && \
 				[ $binary_found -eq 0 ]
 			then
-				binary_path="$(package_get_path "$package")${PATH_GAME}/$binary_file"
+				binary_path="$(package_get_path "$package")${PATH_GAME}/$(application_exe "$application")"
 				error_launcher_missing_binary "$binary_path"
+				return 1
 			fi
 		;;
 		('wine')
-			use_package_specific_value "${application}_EXE"
-			binary_file=$(get_value "${application}_EXE")
-
-			# Check that the name of the binary file is not empty
-			if [ -z "$binary_file" ]; then
-				error_empty_variable "${application}_EXE"
-			fi
-
-			if [ "$binary_file" != 'winecfg' ]; then
-				binary_path="$(package_get_path "$package")${PATH_GAME}/$binary_file"
+			if [ "$(application_exe "$application")" != 'winecfg' ]; then
+				binary_path="$(package_get_path "$package")${PATH_GAME}/$(application_exe "$application")"
 				if \
 					[ $DRY_RUN -eq 0 ] && \
 					[ ! -f "$binary_path" ]
 				then
 					error_launcher_missing_binary "$binary_path"
+					return 1
 				fi
 			fi
 		;;
 		(*)
-			use_package_specific_value "${application}_EXE"
-			binary_file=$(get_value "${application}_EXE")
-
-			# Check that the name of the binary file is not empty
-			if [ -z "$binary_file" ]; then
-				error_empty_variable "${application}_EXE"
-			fi
-
-			binary_path="$(package_get_path "$package")${PATH_GAME}/$binary_file"
+			binary_path="$(package_get_path "$package")${PATH_GAME}/$(application_exe "$application")"
 			if \
 				[ $DRY_RUN -eq 0 ] && \
 				[ ! -f "$binary_path" ]
 			then
 				error_launcher_missing_binary "$binary_path"
+				return 1
 			fi
 		;;
 	esac
@@ -174,8 +147,17 @@ launcher_write_script() {
 			launcher_write_script_game_variables "$target_file"
 			launcher_write_script_residualvm_run "$application" "$target_file"
 		;;
+		('unity3d')
+			launcher_write_script_native_application_variables "$application" "$target_file"
+			launcher_write_script_game_variables "$target_file"
+			launcher_write_script_user_files "$target_file"
+			launcher_write_script_prefix_variables "$target_file"
+			launcher_write_script_prefix_functions "$target_file"
+			launcher_write_script_prefix_build "$target_file"
+			launcher_write_script_unity3d_run "$application" "$target_file"
+		;;
 		('wine')
-			if [ "$application_id" != "${GAME_ID}_winecfg" ]; then
+			if [ "$(application_id "$application")" != "$(game_id)_winecfg" ]; then
 				launcher_write_script_wine_application_variables "$application" "$target_file"
 			fi
 			launcher_write_script_game_variables "$target_file"
@@ -183,7 +165,7 @@ launcher_write_script() {
 			launcher_write_script_prefix_variables "$target_file"
 			launcher_write_script_prefix_functions "$target_file"
 			launcher_write_script_wine_prefix_build "$target_file"
-			if [ "$application_id" = "${GAME_ID}_winecfg" ]; then
+			if [ "$(application_id "$application")" = "$(game_id)_winecfg" ]; then
 				launcher_write_script_winecfg_run "$target_file"
 			else
 				launcher_write_script_wine_run "$application" "$target_file"
@@ -198,9 +180,6 @@ launcher_write_script() {
 			launcher_write_script_prefix_build "$target_file"
 			launcher_write_script_mono_run "$application" "$target_file"
 		;;
-		(*)
-			error_unknown_application_type "$application_type"
-		;;
 	esac
 	cat >> "$target_file" <<- 'EOF'
 	exit 0
@@ -208,11 +187,10 @@ launcher_write_script() {
 
 	# for native applications, add execution permissions to the game binary file
 	case "$application_type" in
-		('native'*)
-			local application_exe
-			use_package_specific_value "${application}_EXE"
-			application_exe="$(get_value "${application}_EXE")"
-			chmod +x "$(package_get_path "$package")${PATH_GAME}/$application_exe"
+		('native'*|'unity3d')
+			local binary_file
+			binary_file="$(package_get_path "$package")${PATH_GAME}/$(application_exe "$application")"
+			chmod +x "$binary_file"
 		;;
 	esac
 
@@ -220,7 +198,7 @@ launcher_write_script() {
 	case "$application_type" in
 		('wine')
 			local winecfg_file
-			winecfg_file="$(package_get_path "$package")${PATH_BIN}/${GAME_ID}_winecfg"
+			winecfg_file="$(package_get_path "$package")${PATH_BIN}/$(game_id)_winecfg"
 			if [ ! -e "$winecfg_file" ]; then
 				launcher_write_script_wine_winecfg "$application"
 			fi
@@ -248,15 +226,13 @@ launcher_write_script_headers() {
 
 # write launcher script game-specific variables
 # USAGE: launcher_write_script_game_variables $file
-# NEEDED VARS: GAME_ID PATH_GAME
-# CALLED BY: launcher_write_script
 launcher_write_script_game_variables() {
 	local file
 	file="$1"
 	cat >> "$file" <<- EOF
 	# Set game-specific values
 
-	GAME_ID='$GAME_ID'
+	GAME_ID='$(game_id)'
 	PATH_GAME='$PATH_GAME'
 
 	EOF
@@ -306,10 +282,85 @@ launcher_write_script_prefix_functions() {
 	local file
 	file="$1"
 	cat >> "$file" <<- 'EOF'
-	# Set prefix-related functions
+	# Set localization and error reporting functions
+
+	# select strings matching the current locale
+	# strings must be prefixed by a two-letter language code and a colon
+	# USAGE: localize $string[…]
+	localize() {
+	    local lang
+	    local string
+	    local match
+	    for lang in "${LANG%%_*}" 'en'; do
+	        for string in "$@"; do
+	            if [ "${string%%:*}" = "$lang" ]; then
+	                echo "${string#*:}"
+	                match=1
+	            fi
+	        done
+	        if [ "$match" ]; then
+	            break
+	        fi
+	    done
+	}
+
+	# print a localized message on standard error output
+	# strings must be prefixed by a two-letter language code and a colon
+	# USAGE: display_message $string[…]
+	display_message() {
+	    local string
+	    localize "$@" | while read -r string; do
+	        printf "$string\n"
+	    done 1>&2
+	}
+
+	# print a localized error message on standard error output
+	# strings must be prefixed by a two-letter language code and a colon
+	# USAGE: display_error $string[…]
+	display_error() {
+	    display_message \
+	        'en:\033[1;31mError:\033[0m' \
+	        'fr:\033[1;31mErreur :\033[0m'
+	    display_message "$@"
+	}
+
+	# print a localized warning message on standard error output
+	# strings must be prefixed by a two-letter language code and a colon
+	# USAGE: display_warning $string[…]
+	display_warning() {
+	    display_message \
+	        'en:\033[1;33mWarning:\033[0m' \
+	        'fr:\033[1;33mAvertissement :\033[0m'
+	    display_message "$@"
+	}
+
+	# Set userdir- and prefix-related functions
+
+	# convert the name of specified user files and directories to upper case
+	# note that only the last component of each matching path is converted
+	# USAGE: userdir_toupper_files $userdir $list
+	userdir_toupper_files() {
+	    local userdir
+	    local list
+	    userdir="$1"
+	    list="$2"
+	    (
+	        cd "$userdir"
+	        for file in $list; do
+	            [ -e "$file" ] || continue
+	            newfile=$(dirname "$file")/$(basename "$file" | tr '[:lower:]' '[:upper:]')
+	            if [ ! -e "$newfile" ]; then
+	                mv "$file" "$newfile"
+	            else
+	                display_warning \
+	                    "en:Cannot overwrite '$userdir/${newfile#./}' with '$userdir/$file'" \
+	                    "fr:Impossible d'écraser '$userdir/${newfile#./}' par '$userdir/$file'"
+	            fi
+	        done
+	    )
+	}
 
 	init_prefix_dirs() {
-	    # shellcheck disable=SC2039
 	    local destination directories
 	    destination="$1"
 	    directories="$2"
@@ -390,6 +441,23 @@ launcher_write_script_prefix_functions() {
 	return 0
 }
 
+# write launcher script prefix prepare hook
+# USAGE: launcher_write_script_prefix_prepare $file
+# CALLED BY: launcher_write_script_prefix_build launcher_write_script_wine_prefix_build
+launcher_write_script_prefix_prepare() {
+	local file
+	file="$1"
+
+	if [ "$PREFIX_PREPARE" ]; then
+		cat >> "$file" <<- EOF
+		$PREFIX_PREPARE
+
+		EOF
+	fi
+
+	return 0
+}
+
 # write launcher script prefix initialization
 # USAGE: launcher_write_script_prefix_build $file
 # CALLED BY: launcher_write_build
@@ -400,11 +468,15 @@ launcher_write_script_prefix_build() {
 	# Build user prefix
 
 	PATH_PREFIX="$XDG_DATA_HOME/play.it/prefixes/$PREFIX_ID"
-	for dir in "$PATH_PREFIX" "$PATH_CONFIG" "$PATH_DATA"; do
-	    if [ ! -e "$dir" ]; then
-	        mkdir --parents "$dir"
-	    fi
-	done
+	mkdir --parents \
+	    "$PATH_PREFIX" \
+	    "$PATH_CONFIG" \
+	    "$PATH_DATA"
+	EOF
+
+	launcher_write_script_prefix_prepare "$file"
+
+	cat >> "$file" <<- 'EOF'
 	(
 	    cd "$PATH_GAME"
 	    find . -type d | while read -r dir; do
@@ -443,152 +515,169 @@ launcher_write_script_prefix_build() {
 
 # write launcher script pre-run actions
 # USAGE: launcher_write_script_prerun $application $file
-# CALLED BY: launcher_write_script_dosbox_run launcher_write_script_native_run launcher_write_script_nativenoprefix_run launcher_write_script_scummvm_run launcher_write_script_residualvm_run launcher_write_script_wine_run
 launcher_write_script_prerun() {
-	# parse arguments
-	local application
-	local file
+	local application file
 	application="$1"
 	file="$2"
 
-	local application_prerun
-	application_prerun="$(get_value "${application}_PRERUN")"
-	if [ "$application_prerun" ]; then
-		cat >> "$file" <<- EOF
-		$application_prerun
-
-		EOF
+	# Return early if there are no pre-run actions for the given application
+	if [ -z "$(application_prerun "$application")" ]; then
+		return 0
 	fi
 
-	return 0
+	cat >> "$file" <<- EOF
+	$(application_prerun "$application")
+
+	EOF
 }
 
 # write launcher script post-run actions
 # USAGE: launcher_write_script_postrun $application $file
-# CALLED BY: launcher_write_script_dosbox_run launcher_write_script_native_run launcher_write_script_nativenoprefix_run launcher_write_script_scummvm_run launcher_write_script_residualvm_run launcher_write_script_wine_run
 launcher_write_script_postrun() {
-	# parse arguments
-	local application
-	local file
+	local application file
 	application="$1"
 	file="$2"
 
-	local application_postrun
-	application_postrun="$(get_value "${application}_POSTRUN")"
-	if [ "$application_postrun" ]; then
-		cat >> "$file" <<- EOF
-		$application_postrun
-
-		EOF
-	fi
-
-	return 0
-}
-
-# write menu entry
-# USAGE: launcher_write_desktop $app
-# NEEDED VARS: OPTION_ARCHITECTURE GAME_ID GAME_NAME PATH_DESK PATH_BIN
-# CALLS: error_missing_argument error_extra_arguments
-launcher_write_desktop() {
-	# check that this has been called with exactly one argument
-	if [ "$#" -eq 0 ]; then
-		error_missing_argument 'launcher_write_desktop'
-	elif [ "$#" -gt 1 ]; then
-		error_extra_arguments 'launcher_write_desktop'
-	fi
-
-	# get the current package
-	local package
-	package=$(package_get_current)
-
-	# Get packages list for the current game
-	local packages_list
-	packages_list=$(packages_get_list)
-
-	# skip any action if called for a package excluded for target architectures
-	if [ "$OPTION_ARCHITECTURE" != 'all' ] && [ -n "${packages_list##*$package*}" ]; then
-		warning_skip_package 'launcher_write_desktop' "$package"
+	# Return early if there are no post-run actions for the given application
+	if [ -z "$(application_postrun "$application")" ]; then
 		return 0
 	fi
 
-	# parse argument
+	cat >> "$file" <<- EOF
+	$(application_postrun "$application")
+
+	EOF
+}
+
+# write the XDG desktop file for the given application
+# USAGE: launcher_write_desktop $application
+launcher_write_desktop() {
 	local application
 	application="$1"
-	if ! testvar "$application" 'APP'; then
-		error_invalid_argument 'application' 'launcher_write_desktop'
+
+	# Skip any action if called for a package excluded for target architectures
+	local package
+	package=$(package_get_current)
+	if \
+		[ "$OPTION_ARCHITECTURE" != 'all' ] \
+		&& ! packages_get_list | grep --quiet "$package"
+	then
+		warning_skip_package 'launcher_write_desktop' "$package"
+		return 0
 	fi
 
-	# get application-specific values
-	local application_id
-	local application_name
-	local application_category
-	local application_type
-	if [ "$application" = 'APP_WINECFG' ]; then
-		application_id="${GAME_ID}_winecfg"
-		# shellcheck disable=SC2153
-		application_name="$GAME_NAME - WINE configuration"
-		application_category='Settings'
-		application_type='wine'
-		application_icon='winecfg'
-	else
-		application_id="$(get_value "${application}_ID")"
-		application_name="$(get_value "${application}_NAME")"
-		application_category="$(get_value "${application}_CAT")"
-		application_type="$(get_value "${application}_TYPE")"
-		: "${application_id:=$GAME_ID}"
-		: "${application_name:=$GAME_NAME}"
-		: "${application_category:=Game}"
-		application_icon="$application_id"
-	fi
-
-	# compute file name and path
-	local target_file
-	target_file="$(package_get_path "$package")${PATH_DESK}/${application_id}.desktop"
-
-	# include full binary path in Exec field if using non-standard installation prefix
-	local exec_field
-	case "$OPTION_PREFIX" in
-		('/usr'|'/usr/local')
-			exec_field="$application_id"
-		;;
-		(*' '*)
-			# enclose the path in single quotes if it includes spaces
-			exec_field="'$PATH_BIN/$application_id'"
-		;;
-		(*)
-			exec_field="$PATH_BIN/$application_id"
-		;;
-	esac
-
 	# if called in dry run mode, return before writing anything
 	if [ "$DRY_RUN" -eq 1 ]; then
 		return 0
 	fi
 
 	# write desktop file
-	mkdir --parents "$(dirname "$target_file")"
-	cat >> "$target_file" <<- EOF
+	local desktop_file
+	desktop_file=$(launcher_desktop_filepath "$application")
+	mkdir --parents "$(dirname "$desktop_file")"
+	launcher_desktop "$application" > "$desktop_file"
+
+	# for WINE applications, write desktop file for winecfg
+	if [ "$application" != 'APP_WINECFG' ]; then
+		local application_type
+		application_type=$(application_type "$application")
+		case "$application_type" in
+			('wine')
+				local package_path winecfg_desktop
+				package_path=$(package_get_path "$package")
+				game_id=$(game_id)
+				winecfg_desktop="${package_path}${PATH_DESK}/${game_id}_winecfg.desktop"
+				if [ ! -e "$winecfg_desktop" ]; then
+					APP_WINECFG_ID="$(game_id)_winecfg"
+					APP_WINECFG_NAME="$(game_name) - WINE configuration"
+					APP_WINECFG_CAT='Settings'
+					export APP_WINECFG_ID APP_WINECFG_NAME APP_WINECFG_CAT
+					launcher_write_desktop 'APP_WINECFG'
+				fi
+			;;
+		esac
+	fi
+
+	return 0
+}
+
+# print the content of the XDG desktop file for the given application
+# USAGE: launcher_desktop $application
+# RETURN: the full content of the XDG desktop file
+launcher_desktop() {
+	local application
+	application="$1"
+
+	###
+	# TODO
+	# This should be moved to a dedicated function,
+	# probably in a 20_icons.sh source file
+	###
+	# get icon name
+	local application_icon
+	if [ "$application" = 'APP_WINECFG' ]; then
+		application_icon='winecfg'
+	else
+		application_icon=$(application_id "$application")
+	fi
+
+	cat <<- EOF
 	[Desktop Entry]
 	Version=1.0
 	Type=Application
-	Name=$application_name
+	Name=$(application_name "$application")
 	Icon=$application_icon
-	Exec=$exec_field
-	Categories=$application_category
+	$(launcher_desktop_exec "$application")
+	Categories=$(application_category "$application")
 	EOF
+}
 
-	# for WINE applications, write desktop file for winecfg
-	case "$application_type" in
-		('wine')
-			local winecfg_desktop
-			winecfg_desktop="$(package_get_path "$package")${PATH_DESK}/${GAME_ID}_winecfg.desktop"
-			if [ ! -e "$winecfg_desktop" ]; then
-				launcher_write_desktop 'APP_WINECFG'
-			fi
+# print the full path to the XDG desktop file for the given application
+# USAGE: launcher_desktop_filepath $application
+# RETURN: an absolute file path
+launcher_desktop_filepath() {
+	local application application_id package package_path
+	application="$1"
+	application_id=$(application_id "$application")
+	package=$(package_get_current)
+	package_path=$(package_get_path "$package")
+
+	printf '%s/%s.desktop' \
+		"${package_path}${PATH_DESK}" \
+		"$application_id"
+}
+
+# print the XDG desktop "Exec" field for the given application
+# USAGE: launcher_desktop_exec $application
+# RETURN: the "Exec" field string, including escaping if required
+launcher_desktop_exec() {
+	local application
+	application="$1"
+
+	# Enclose the path in single quotes if it includes spaces
+	local field_format
+	case "$OPTION_PREFIX" in
+		(*' '*)
+			field_format="Exec='%s'"
+		;;
+		(*)
+			field_format='Exec=%s'
 		;;
 	esac
 
-	return 0
+	# Use the full path for non-standard prefixes
+	local field_value
+	case "$OPTION_PREFIX" in
+		('/usr'|'/usr/local')
+			field_value=$(application_id "$application")
+		;;
+		(*)
+			field_value="$PATH_BIN/$(application_id "$application")"
+		;;
+	esac
+
+	# shellcheck disable=SC2059
+	printf "$field_format" "$field_value"
 }
 
 # write both launcher script and menu entry for a single application
@@ -597,17 +686,14 @@ launcher_write_desktop() {
 # CALLS: launcher_write_script launcher_write_desktop
 # CALLED BY: launchers_write
 launcher_write() {
-	# get the current package
+	# Check that the current package is part of the target architectures
 	local package
 	package=$(package_get_current)
-
-	# Get packages list for the current game
-	local packages_list
-	packages_list=$(packages_get_list)
-
-	# skip any action if called for a package excluded for target architectures
-	if [ "$OPTION_ARCHITECTURE" != 'all' ] && [ -n "${packages_list##*$package*}" ]; then
-		warning_skip_package 'launcher_write_script' "$package"
+	if \
+		[ "$OPTION_ARCHITECTURE" != 'all' ] \
+		&& ! packages_get_list | grep --quiet "$package"
+	then
+		warning_skip_package 'launcher_write' "$package"
 		return 0
 	fi
 
@@ -618,35 +704,38 @@ launcher_write() {
 	return 0
 }
 
-# write both launcher script and menu entry for a list of applications
-# USAGE: launchers_write $application[…]
-# NEEDED VARS: OPTION_ARCHITECTURE
-# CALLS: launcher_write
+# write both a launcher script and a menu entry for each application from a list
+# USAGE: launchers_write [$application…]
+# RETURN: nothing
 launchers_write() {
-
 	debug_entering_function 'launchers_write' 2
 
-	# get the current package
+	# Check that the current package is part of the target architectures
 	local package
 	package=$(package_get_current)
-
-	# Get packages list for the current game
-	local packages_list
-	packages_list=$(packages_get_list)
-
-	# skip any action if called for a package excluded for target architectures
-	if [ "$OPTION_ARCHITECTURE" != 'all' ] && [ -n "${packages_list##*$package*}" ]; then
-		warning_skip_package 'launcher_write_script' "$package"
+	if \
+		[ "$OPTION_ARCHITECTURE" != 'all' ] \
+		&& ! packages_get_list | grep --quiet "$package"
+	then
+		warning_skip_package 'launchers_write' "$package"
+		debug_leaving_function 'launchers_write' 2
 		return 0
 	fi
 
+	# If called with no argument, default to handling the full list of applications
+	if [ $# -eq 0 ]; then
+		# shellcheck disable=SC2046
+		launchers_write $(applications_list)
+		debug_leaving_function 'launchers_write' 2
+		return 0
+	fi
+
+	# Write a launcher script and a menu entry for each application
 	local application
 	for application in "$@"; do
 		launcher_write "$application"
 	done
 
 	debug_leaving_function 'launchers_write' 2
-
-	return 0
 }
 
