@@ -2,21 +2,16 @@
 # USAGE: launcher_write_script_residualvm_application_variables $application $file
 # CALLED BY: launcher_write_script
 launcher_write_script_residualvm_application_variables() {
-	# parse arguments
-	local application
-	local file
+	local application file
 	application="$1"
 	file="$2"
-
-	# compute application-specific variables values
-	local application_residualid
-	use_package_specific_value "${application}_RESIDUALID"
-	application_residualid="$(get_value "${application}_RESIDUALID")"
+	local application_residualvm_residualid
+	application_residualvm_residualid=$(application_residualvm_residualid "$application")
 
 	cat >> "$file" <<- EOF
 	# Set application-specific values
 
-	RESIDUALVM_ID='$application_residualid'
+	RESIDUALVM_ID='$application_residualvm_residualid'
 
 	EOF
 	return 0
@@ -41,7 +36,7 @@ launcher_write_script_residualvm_run() {
 	launcher_write_script_prerun "$application" "$file"
 
 	cat >> "$file" <<- 'EOF'
-	residualvm -p "$PATH_GAME" $APP_OPTIONS $@ $RESIDUALVM_ID
+	residualvm -p "$PATH_GAME" "$@" "$RESIDUALVM_ID"
 
 	EOF
 
