@@ -5,15 +5,16 @@ print_instructions_arch() {
 	local str_format
 	printf 'pacman -U'
 
-	# Get packages list for the current game
-	local packages_list
-	packages_list=$(packages_get_list)
-
 	for pkg in "$@"; do
-		if [ "$OPTION_ARCHITECTURE" != all ] && [ -n "${packages_list##*$pkg*}" ]; then
+		# Check that the current package is part of the target architectures
+		if \
+			[ "$OPTION_ARCHITECTURE" != 'all' ] \
+			&& ! packages_get_list | grep --quiet "$pkg"
+		then
 			warning_skip_package 'print_instructions_arch' "$pkg"
 			return 0
 		fi
+
 		pkg_path=$(realpath "$(get_value "${pkg}_PKG")")
 		if [ -z "${pkg_path##* *}" ]; then
 			str_format=' "%s"'
