@@ -16,7 +16,6 @@ error_invalid_argument() {
 	esac
 	print_error
 	printf "$message" "$var" "$func" "$value"
-	return 1
 }
 
 # display an error when a function is called without an argument, but is expecting some
@@ -35,7 +34,6 @@ error_missing_argument() {
 	esac
 	print_error
 	printf "$message" "$function"
-	return 1
 }
 
 # display an error when a function is called with multiple arguments, but is expecting no more than one
@@ -54,7 +52,6 @@ error_extra_arguments() {
 	esac
 	print_error
 	printf "$message" "$function"
-	return 1
 }
 
 # display an error when a file is expected and something else has been given
@@ -73,7 +70,6 @@ error_not_a_file() {
 	esac
 	print_error
 	printf "$message" "$param"
-	return 1
 }
 
 # display an error when an unknown application type is used
@@ -92,9 +88,10 @@ error_unknown_application_type() {
 			message="$message"'Please report this issue in our bug tracker: %s\n'
 		;;
 	esac
+
 	print_error
+	# shellcheck disable=SC2059
 	printf "$message" "$application_type" "$PLAYIT_GAMES_BUG_TRACKER_URL"
-	return 1
 }
 
 # display an error when the available tar implementation is not supported
@@ -116,7 +113,6 @@ error_unknown_tar_implementation() {
 	esac
 	print_error
 	printf "$message" "$PLAYIT_BUG_TRACKER_URL"
-	return 1
 }
 
 # display a message when a required dependency is missing
@@ -136,7 +132,6 @@ error_dependency_not_found() {
 	esac
 	print_error
 	printf "$message" "$command_name" "$provider"
-	return 1
 }
 
 # display an error message if an icon dependency is missing
@@ -159,7 +154,6 @@ error_icon_dependency_not_found() {
 		;;
 	esac
 	printf "$message"
-	return 1
 }
 
 # display an error when trying to extract an archive but no extractor is present
@@ -180,7 +174,6 @@ error_archive_no_extractor_found() {
 	esac
 	print_error
 	printf "$message" "$archive_type" "$PLAYIT_GAMES_BUG_TRACKER_URL"
-	return 1
 }
 
 # Display an error when trying to write a launcher for a missing binary
@@ -202,7 +195,6 @@ error_launcher_missing_binary() {
 	esac
 	print_error
 	printf "$message" "$binary" "$PLAYIT_GAMES_BUG_TRACKER_URL"
-	return 1
 }
 
 # display an error when the value assigned to a given option is not valid
@@ -224,14 +216,12 @@ error_option_invalid() {
 	esac
 	print_error
 	printf "$message" "$option_value" "$option_name" "$option_name"
-	return 1
 }
 
 # display an error when the compression method is not compatible with the
 # package format
 # USAGE: error_compression_invalid
 error_compression_invalid() {
-	# shellcheck disable=SC2039
 	local compression_method allowed_values package_format message
 
 	compression_method="$OPTION_COMPRESSION"
@@ -254,7 +244,6 @@ error_compression_invalid() {
 	print_error
 	# shellcheck disable=SC2059
 	printf "$message" "$compression_method" "$package_format" "$allowed_values"
-	return 1
 }
 
 # display an error message when a required archive is not found
@@ -282,7 +271,6 @@ error_archive_not_found() {
 	print_error
 	printf "$message"
 	information_archives_list "$@"
-	return 1
 }
 
 # display an error message when we failed to guess the type of an archive
@@ -301,7 +289,6 @@ error_archive_type_not_set() {
 	esac
 	print_error
 	printf "$message" "$archive"
-	return 1
 }
 
 # display an error message when an integrity check fails
@@ -322,7 +309,6 @@ error_hashsum_mismatch() {
 	esac
 	print_error
 	printf "$message" "$file"
-	return 1
 }
 
 # display an error when the selected architecture is not supported
@@ -341,7 +327,6 @@ error_architecture_not_supported() {
 	esac
 	print_error
 	printf "$message" "$architecture"
-	return 1
 }
 
 # display an error when a variable required by the calling function is not set
@@ -361,7 +346,6 @@ error_variable_not_set() {
 	esac
 	print_error
 	printf "$message" "$function" "$variable"
-	return 1
 }
 
 # display an error if there is not enough free storage space
@@ -383,7 +367,6 @@ error_not_enough_free_space() {
 	for directory in "$@"; do
 		printf '%s\n' "$directory"
 	done
-	return 1
 }
 
 # print error when available version of innoextract is too old
@@ -410,7 +393,6 @@ error_innoextract_version_too_old() {
 	printf "$message" "$archive" \
 		'https://forge.dotslashplay.it/play.it/doc/-/wikis/distributions/debian#available-innoextract-version-is-too-old' \
 		'https://forge.dotslashplay.it/play.it/doc/-/wikis/distributions/ubuntu#innoextract-version-is-too-old'
-	return 1
 }
 
 # diplay an error message if an icon file can not be found
@@ -431,7 +413,6 @@ error_icon_file_not_found() {
 	esac
 	print_error
 	printf "$message" "$file" "$PLAYIT_GAMES_BUG_TRACKER_URL"
-	return 1
 }
 
 # display an error when called with an unknown option
@@ -450,7 +431,6 @@ error_option_unknown() {
 	esac
 	print_error
 	printf "$message" "$option_name"
-	return 1
 }
 
 # display an error when a given path is not a directory
@@ -469,7 +449,6 @@ error_not_a_directory() {
 	esac
 	print_error
 	printf "$message" "$path"
-	return 1
 }
 
 # display an error when a given path is not writable
@@ -488,7 +467,6 @@ error_not_writable() {
 	esac
 	print_error
 	printf "$message" "$path"
-	return 1
 }
 
 # display an error when a function has been given an unexpected empty string
@@ -510,7 +488,6 @@ error_empty_string() {
 	esac
 	print_error
 	printf "$message" "$string" "$function" "$PLAYIT_BUG_TRACKER_URL"
-	return 1
 }
 
 # display an error when a required command is missing, but a function was expecting it to be available
@@ -532,7 +509,6 @@ error_unavailable_command() {
 	esac
 	print_error
 	printf "$message" "$command" "$function" "$PLAYIT_BUG_TRACKER_URL"
-	return 1
 }
 
 # display an error when the calling script does not set its target library version
@@ -553,7 +529,6 @@ error_missing_target_version() {
 	esac
 	print_error
 	printf "$message" "$PLAYIT_GAMES_BUG_TRACKER_URL"
-	return 1
 }
 
 # display an error when the calling script is not compatible with the provided library version
@@ -577,7 +552,6 @@ error_incompatible_versions() {
 		"$VERSION_MAJOR_PROVIDED.$VERSION_MINOR_PROVIDED" \
 		"$VERSION_MAJOR_TARGET.$VERSION_MINOR_TARGET" \
 		"$((VERSION_MAJOR_TARGET + 1)).0"
-	return 1
 }
 
 # display an error when no game script has been found for a given archive
@@ -596,7 +570,6 @@ error_no_script_found_for_archive() {
 	esac
 	print_error
 	printf "$message" "$archive"
-	return 1
 }
 
 # display an error when a variable is empty
@@ -617,17 +590,14 @@ error_empty_variable() {
 	esac
 	print_error
 	printf "$message" "$variable" "$PLAYIT_GAMES_BUG_TRACKER_URL"
-	return 1
 }
 
 # display an error when trying to use a case-insensitive filesystem
 # USAGE: error_case_insensitive_filesystem_is_not_supported $directory
 error_case_insensitive_filesystem_is_not_supported() {
-	# shellcheck disable=SC2039
 	local directory
 	directory="$1"
 
-	# shellcheck disable=SC2039
 	local message
 	# shellcheck disable=SC2031
 	case "${LANG%_*}" in
@@ -644,19 +614,14 @@ error_case_insensitive_filesystem_is_not_supported() {
 	print_error
 	# shellcheck disable=SC2059
 	printf "$message" "$directory"
-
-	return 1
 }
 
-
 # display an error when trying to use a filesystem without support for UNIX permissions
 # USAGE: error_unix_permissions_support_is_required $directory
 error_unix_permissions_support_is_required() {
-	# shellcheck disable=SC2039
 	local directory
 	directory="$1"
 
-	# shellcheck disable=SC2039
 	local message
 	# shellcheck disable=SC2031
 	case "${LANG%_*}" in
@@ -673,7 +638,357 @@ error_unix_permissions_support_is_required() {
 	print_error
 	# shellcheck disable=SC2059
 	printf "$message" "$directory"
+}
 
+# display an error when trying to get the current archive but none is set
+# USAGE: error_archive_unset
+error_archive_unset() {
+	local message
+	# shellcheck disable=SC2031
+	case "${LANG%_*}" in
+		('fr')
+			message='Aucune archive nʼest définie, mais une est attendue à ce point de lʼexécution.\n'
+		;;
+		('en'|*)
+			message='No archive is set, but one is expected at this step.\n'
+		;;
+	esac
+	print_error
+	# shellcheck disable=SC2059
+	printf "$message"
+}
+
+# display an error when trying to use an unkown type of context
+# valid context types are:
+# - archive
+# - package
+# USAGE: error_context_invalid $context
+error_context_invalid() {
+	local context
+	context="$1"
+
+	local message
+	# shellcheck disable=SC2031
+	case "${LANG%_*}" in
+		('fr')
+			message='Un type de contexte inattendu a été demandé : %s\n'
+			message="$message"'Seuls les types suivants sont valides :\n'
+			message="$message"'\t- archive\n'
+			message="$message"'\t- package\n'
+		;;
+		('en'|*)
+			message='An unexpected context type has been required: %s\n'
+			message="$message"'Only the following types are valid:\n'
+			message="$message"'\t- archive\n'
+			message="$message"'\t- package\n'
+		;;
+	esac
+	print_error
+	# shellcheck disable=SC2059
+	printf "$message" "$context"
+}
+
+# display an error when using an invalid format for game id
+# USAGE: error_game_id_invalid $game_id
+error_game_id_invalid() {
+	local game_id message
+	game_id="$1"
+	# shellcheck disable=SC2031
+	case "${LANG%_*}" in
+		('fr')
+			message='Lʼid de jeu fourni ne correspond pas au format attendu : "%s"\n'
+			message="$message"'Cette valeur ne peut utiliser que des caractères du set [-a-z0-9],'
+			message="$message"' et ne peut ni débuter ni sʼachever par un tiret.\n'
+		;;
+		('en'|*)
+			message='The provided game id is not using the expected format: "%s"\n'
+			message="$message"'The value should only include characters from the set [-a-z0-9],'
+			message="$message"' and can not begin nor end with an hyphen.\n'
+		;;
+	esac
+
+	print_error
+	# shellcheck disable=SC2059
+	printf "$message" "$game_id"
+}
+
+# display an error when using an invalid format for an application id
+# USAGE: error_application_id_invalid $application $application_id
+error_application_id_invalid() {
+	local application application_id
+	application="$1"
+	application_id="$2"
+
+	local message
+	# shellcheck disable=SC2031
+	case "${LANG%_*}" in
+		('fr')
+			message='Lʼid fourni pour lʼapplication %s ne correspond pas au format attendu : "%s"\n'
+			message="$message"'Cette valeur ne peut utiliser que des caractères du set [-a-z0-9],'
+			message="$message"' et ne peut ni débuter ni sʼachever par un tiret.\n'
+		;;
+		('en')
+			message='The id provided for application %s is not using the expected format: "%s"\n'
+			message="$message"'The value should only include characters from the set [-a-z0-9],'
+			message="$message"' and can not begin nor end with an hyphen.\n'
+		;;
+	esac
+
+	print_error
+	# shellcheck disable=SC2059
+	printf "$message" "$application" "$application_id"
+}
+
+# display an error when using an invalid format for an application ScummVM id
+# USAGE: error_application_scummid_invalid $application $application_scummid
+error_application_scummid_invalid() {
+	local application application_scummid
+	application="$1"
+	application_scummid="$2"
+
+	local message
+	# shellcheck disable=SC2031
+	case "${LANG%_*}" in
+		('fr')
+			message='Lʼid ScummVM fourni pour lʼapplication %s ne semble pas correct : "%s"\n'
+			message="$message"'Une liste de valeurs acceptées peut se trouver sur le site Web de ScummVM : \n%s\n'
+		;;
+		('en')
+			message='The ScummVM id provided for application %s does not seem correct: "%s"\n'
+			message="$message"'A list of valid values can be found on ScummVM website: \n%s\n'
+		;;
+	esac
+
+	print_error
+	# shellcheck disable=SC2059
+	printf "$message" \
+		"$application" \
+		"$application_scummid" \
+		'https://www.scummvm.org/compatibility/'
+}
+
+# display an error when using an invalid format for an application ResidualVM id
+# USAGE: error_application_residualid_invalid $application $application_residualid
+error_application_residualid_invalid() {
+	local application application_residualid
+	application="$1"
+	application_residualid="$2"
+
+	local message
+	# shellcheck disable=SC2031
+	case "${LANG%_*}" in
+		('fr')
+			message='Lʼid ResidualVM fourni pour lʼapplication %s ne semble pas correct : "%s"\n'
+			message="$message"'Une liste de valeurs acceptées peut se trouver sur le site Web de ResidualVM : \n%s\n'
+		;;
+		('en')
+			message='The ResidualVM id provided for application %s does not seem correct: "%s"\n'
+			message="$message"'A list of valid values can be found on ResidualVM website: \n%s\n'
+		;;
+	esac
+
+	print_error
+	# shellcheck disable=SC2059
+	printf "$message" \
+		"$application" \
+		"$application_residualid" \
+		'https://www.residualvm.org/compatibility/'
+}
+
+# display an error when APP_xxx_EXE is unset but the application requires it
+# USAGE: error_application_exe_empty $application $application_type
+error_application_exe_empty() {
+	local application application_type
+	application="$1"
+	application_type="$2"
+
+	local message
+	# shellcheck disable=SC2031
+	case "${LANG%_*}" in
+		('fr')
+			message='%s nʼest pas défini, mais cette valeur est requise pour les applications utilisant le type "%s".\n'
+		;;
+		('en')
+			message='%s is not set, but is required for applications using "%" type.\n'
+		;;
+	esac
+
+	print_error
+	# shellcheck disable=SC2059
+	printf "$message" "${application}_EXE" "$application_type"
+}
+
+# display an error when a variable is spanning multiple lines
+# USAGE: error_variable_multiline $variable_name
+error_variable_multiline() {
+	local variable_name
+	variable_name="$1"
+
+	local message
+	# shellcheck disable=SC2031
+	case "${LANG%_*}" in
+		('fr')
+			message='La valeur %s sʼétend sur plusieurs lignes, ce qui nʼest pas autorisé.\n'
+		;;
+		('en')
+			message='%s value is spanning multiple lines, but this is not allowed.\n'
+		;;
+	esac
+
+	print_error
+	# shellcheck disable=SC2059
+	printf "$message" "$variable_name"
+}
+
+# display an error when calling a type-restricted function on the wrong application type
+# USAGE: error_application_wrong_type $function_name $application_type
+error_application_wrong_type() {
+	local function_name application_type
+	function_name="$1"
+	application_type="$2"
+
+	local message
+	# shellcheck disable=SC2031
+	case "${LANG%_*}" in
+		('fr')
+			message='%s ne peut pas être appelée sur les applications utilisant le type "%s".\n'
+		;;
+		('en')
+			message='%s can not be called on applications using "%s" type.\n'
+		;;
+	esac
+
+	print_error
+	# shellcheck disable=SC2059
+	printf "$message" "$function_name" "$application_type"
+}
+
+# displays an error when no valid candidates for ./play.it temporary directory
+# has been found
+# USAGE: error_no_valid_temp_dir_found $directory[…]
+error_no_valid_temp_dir_found() {
+	local message
+	# shellcheck disable=SC2031
+	case "${LANG%_*}" in
+		('fr')
+			message='Aucun réportoire testé ne peut servir de répertoire
+			temporaire pour ./play.it :\n'
+		;;
+		('en'|*)
+			message='No tested repository can be used as ./play.it temporary
+			directory:\n'
+		;;
+	esac
+
+	print_error
+	# shellcheck disable=SC2059
+	printf "$message"
+	printf '%s\n' "$@"
+}
+
+# display an error when the path to a given icon is unset but we try to use it
+# USAGE: error_icon_path_empty $icon
+error_icon_path_empty() {
+	local icon
+	icon="$1"
+
+	local message
+	# shellcheck disable=SC2031
+	case "${LANG%_*}" in
+		('fr')
+			message='%s nʼest pas défini, mais il y a eu une tentative de récupérer le chemin de cette icône.\n'
+		;;
+		('en')
+			message='%s is not set, but there has been a request for this icon path.\n'
+		;;
+	esac
+
+	print_error
+	# shellcheck disable=SC2059
+	printf "$message" "$icon"
+}
+
+# display an error when the config file is not found
+# USAGE: error_config_file_not_found $config_file_path
+error_config_file_not_found() {
+	local message
+	local config_file_path
+
+	config_file_path="$1"
+
+	# shellcheck disable=SC2031
+	case "${LANG%_*}" in
+		('fr')
+			message='Le fichier de configuration %s nʼa pas pu être trouvé.\n'
+			;;
+		('en'|*)
+			message='The configuration file %s has not been found.\n'
+			;;
+	esac
+	print_error
+	printf "$message" "$config_file_path"
 	return 1
 }
 
+# No default content path is set
+# USAGE: error_no_content_path_default
+error_no_content_path_default() {
+	local message
+	# shellcheck disable=SC2031
+	case "${LANG%_*}" in
+		('fr')
+			message='CONTENT_PATH_DEFAULT nʼest pas défini, mais il a été requis.\n'
+			message="$message"'Merci de signaler cette erreur sur notre outil de gestion de bugs : %s\n'
+		;;
+		('en'|*)
+			message='CONTENT_PATH_DEFAULT is not set, but it has been required.\n'
+			message="$message"'Please report this issue in our bug tracker: %s\n'
+		;;
+	esac
+
+	print_error
+	# shellcheck disable=SC2059
+	printf "$message" "$PLAYIT_GAMES_BUG_TRACKER_URL"
+}
+
+# the current package is not part of the full list of packages to generate
+# USAGE: error_package_not_in_list $package
+error_package_not_in_list() {
+	local message package
+	package="$1"
+	# shellcheck disable=SC2031
+	case "${LANG%_*}" in
+		('fr')
+			message='Cet identifiant de paquet ne correspond pas à un paquet à construire : %s\n'
+		;;
+		('en'|*)
+			message='The following package identifier is not part of the list of packages to generate: %s\n'
+		;;
+	esac
+
+	print_error
+	# shellcheck disable=SC2059
+	printf "$message" "$package"
+}
+
+# An icon file with an unsupported MIME type has been passed
+# USAGE: error_icon_unsupported_type $icon_file $icon_type
+error_icon_unsupported_type() {
+	local icon_file icon_type message
+	icon_file="$1"
+	icon_type="$2"
+	# shellcheck disable=SC2031
+	case "${LANG%_*}" in
+		('fr')
+			message='Le fichier dʼicône suivant est du type MIME "%s", qui nʼest pas pris en charge : %s\n'
+		;;
+		('en'|*)
+			message='The following icon file is of the "%s" MIME type, that is not supported: %s\n'
+		;;
+	esac
+
+	print_error
+	# shellcheck disable=SC2059
+	printf "$message" "$icon_type" "$icon_file"
+}
+
