@@ -1,3 +1,28 @@
+# Keep compatibility with 2.13 and older
+
+icons_include_png_from_directory() {
+	icons_include_from_directory "$@"
+}
+
+sort_icons() {
+	for application in "$@"; do
+		icons_include_png_from_directory "$application" "${PLAYIT_WORKDIR}/icons"
+	done
+}
+
+icon_get_resolution_from_file() {
+	resolution=$(icon_get_resolution "$@")
+	export resolution
+}
+
+use_archive_specific_value() {
+	export "$1=$(get_context_specific_value 'archive' "$1")"
+}
+
+use_package_specific_value() {
+	export "$1=$(get_context_specific_value 'package' "$1")"
+}
+
 # Keep compatibility with 2.12 and older
 
 archives_get_list() {
@@ -18,7 +43,7 @@ set_architecture() {
 icons_linking_postinst() {
 	if \
 		! version_is_at_least '2.8' "$target_version" && \
-		[ -z "${PACKAGES_LIST##*PKG_DATA*}" ]
+		packages_get_list | grep --quiet --fixed-strings 'PKG_DATA'
 	then
 		(
 			PKG='PKG_DATA'
@@ -31,7 +56,6 @@ icons_linking_postinst() {
 
 archive_set() {
 	archive_initialize_optional "$@"
-	# shellcheck disable=SC2039
 	local archive
 	archive=$(archive_find_from_candidates "$@")
 	if [ -n "$archive" ]; then
@@ -125,6 +149,7 @@ compat_pkg_write_gentoo_prerm() {
 
 liberror() {
 	error_invalid_argument "$1" "$2"
+	return 1
 }
 
 skipping_pkg_warning() {
@@ -133,10 +158,12 @@ skipping_pkg_warning() {
 
 archive_set_error_not_found() {
 	error_archive_not_found "$@"
+	return 1
 }
 
 archive_guess_type_error() {
 	error_archive_type_not_set "$1"
+	return 1
 }
 
 archive_print_file_in_use() {
@@ -145,6 +172,7 @@ archive_print_file_in_use() {
 
 archive_integrity_check_error() {
 	error_hashsum_mismatch "$1"
+	return 1
 }
 
 select_package_architecture_warning_unavailable() {
@@ -153,6 +181,7 @@ select_package_architecture_warning_unavailable() {
 
 select_package_architecture_error_unknown() {
 	error_architecture_not_supported "$OPTION_ARCHITECTURE"
+	return 1
 }
 
 select_package_architecture_warning_unsupported() {
@@ -161,39 +190,48 @@ select_package_architecture_warning_unsupported() {
 
 error_no_pkg() {
 	error_variable_not_set "$1" '$PKG'
+	return 1
 }
 
 set_temp_directories_error_no_size() {
 	error_variable_not_set 'set_temp_directories' '$ARCHIVE_SIZE'
+	return 1
 }
 
 prepare_package_layout_error_no_list() {
 	error_variable_not_set 'prepare_package_layout' '$PACKAGES_LIST'
+	return 1
 }
 
 organize_data_error_missing_pkg() {
 	error_variable_not_set 'organize_data' '$PKG'
+	return 1
 }
 
 icon_path_empty_error() {
 	error_variable_not_set 'icons_get_from_path' '$'"$1"
+	return 1
 }
 
 set_temp_directories_error_not_enough_space() {
 	# shellcheck disable=SC2046
 	error_not_enough_free_space $(temporary_directories_list_candidates)
+	return 1
 }
 
 archive_extraction_innosetup_error_version() {
 	error_innoextract_version_too_old "$1"
+	return 1
 }
 
 icon_file_not_found_error() {
 	error_icon_file_not_found "$1"
+	return 1
 }
 
 missing_pkg_error() {
 	error_invalid_argument 'PKG' "$1"
+	return 1
 }
 
 pkg_build_print_already_exists() {
@@ -238,8 +276,28 @@ write_launcher() {
 
 # Keep compatibility with 2.8 and older
 
+icon_get_resolution_pre_2_8() {
+	local image_file image_resolution_string image_resolution string_field
+	image_file="$1"
+	string_field=2
+	while
+		[ -z "$image_resolution" ] || \
+		[ -n "$(printf '%s' "$image_resolution" | sed 's/[0-9]*x[0-9]*//')" ]
+	do
+		if [ -n "${file##* *}" ]; then
+			image_resolution_string=$(identify $image_file | cut --delimiter=' ' --fields=$string_field)
+		else
+			image_resolution_string=$(identify "$image_file" | cut --delimiter=' ' --fields=$string_field)
+		fi
+		image_resolution="${image_resolution_string%+0+0}"
+		string_field=$((string_field + 1))
+	done
+
+	printf '%s' "$image_resolution"
+	return 0
+}
+
 icon_check_file_existence_pre_2_8() {
-	# shellcheck disable=SC2039
 	local directory file
 	directory="$1"
 	file="$2"
@@ -252,10 +310,9 @@ icon_check_file_existence_pre_2_8() {
 		return 1
 	else
 		# get the real file name from its globbed one
-		# shellcheck disable=SC2039
 		local file_path
 		file_path=$(eval printf '%s' "$directory/$file")
-		file="${file_path#${directory}/}"
+		file=${file_path#"${directory}/"}
 	fi
 
 	printf '%s' "$file"
@@ -309,5 +366,6 @@ set_archive() {
 
 set_archive_error_not_found() {
 	archive_set_error_not_found "$@"
+	return 1
 }
 
